searchData={"items":[{"type":"module","doc":"A set of utils to programmatically call your own endpoints\n\nIt happens that sometimes you need to programmatically call your own endpoint (for instance Phoenix\nendpoint). One could use an HTTP client locally calling your own deployed instance, but it's\ncumbersome, hard to test and comes with an overhead.\n\nThis library intends to provide with a set of function to directly call your endpoint. It is very\nsimilar to `Phoenix.ConnTest` and reimplements a Plug adapter for this purpose.\n\nYou can form a new request from a Phoenix endpoint:\n\n```elixir\nMyAppWeb.Endpoint\n|> PlugLoopback.from_phoenix_endpoint()\n|> PlugLoopback.get(\"/some/path\", [{\"some\", \"header\"}])\n|> Plug.Conn.put_req_header(\"another\", \"header\")\n|> PlugLoopback.run()\n```\n\nor replay any `Plug.Conn{}`:\n\n```elixir\nconn\n|> PlugLoopback.replay()\n|> PlugLoopback.run() # Here is a very good opportunity to create an infinite loop!\n```\n\n> #### Warning {: .warning}\n>\n> For some very good reasons, you must run these commands in their own process. **Do not** run\n> it in a process that already processed a `%Plug.Conn{}`.","title":"PlugLoopback","ref":"PlugLoopback.html"},{"type":"function","doc":"Shortcut for `request/1` with `\"DELETE\"` method","title":"PlugLoopback.delete/4","ref":"PlugLoopback.html#delete/4"},{"type":"function","doc":"Creates a new fresh conn from a Phoenix endpoint\n\nPeer data IP address is set to `127.0.0.1`.\n\nAfter calling this function, you need to form a request with `get/4`, `post/4`, `put/4`, `patch/4`\n`head/4`, `delete/4` or the generic `request/5`.","title":"PlugLoopback.from_phoenix_endpoint/1","ref":"PlugLoopback.html#from_phoenix_endpoint/1"},{"type":"function","doc":"Shortcut for `request/1` with `\"GET\"` method","title":"PlugLoopback.get/4","ref":"PlugLoopback.html#get/4"},{"type":"function","doc":"Shortcut for `request/1` with `\"HEAD\"` method","title":"PlugLoopback.head/4","ref":"PlugLoopback.html#head/4"},{"type":"function","doc":"Shortcut for `request/1` with `\"PATCH\"` method","title":"PlugLoopback.patch/4","ref":"PlugLoopback.html#patch/4"},{"type":"function","doc":"Shortcut for `request/1` with `\"POST\"` method","title":"PlugLoopback.post/4","ref":"PlugLoopback.html#post/4"},{"type":"function","doc":"Shortcut for `request/1` with `\"PUT\"` method","title":"PlugLoopback.put/4","ref":"PlugLoopback.html#put/4"},{"type":"function","doc":"Creates a new fresh conn ready to request from another conn\n\nState is reinitialized so that the returned conn is cleaned to be requested again.\n\nIf a Phoenix endpoint was used, then it is recognized and the result conn can be run\nwith `run/1`. Otherwise you need to call the next plug yourself, like:\n\n```elixir\nconn\n|> PlugLoopback.replay()\n|> MyOtherPlugModule.call(opts)\n```\n\nor if the conn is from a phoenix endpoint:\n\n```elixir\nconn\n|> PlugLoopback.replay()\n|> # modify the conn, for instance by setting new request headers\n|> PlugLoopback.run()\n```\n\nPeer data is copied from the original conn.","title":"PlugLoopback.replay/1","ref":"PlugLoopback.html#replay/1"},{"type":"function","doc":"Readies a conn for requesting\n\nThis function sets the necessary information to make a request: method, path, headers and body.\n\nWhen setting a body, make sure to encode it to a binary **and** to set the correct\n`content-type` header. This library doesn't do it for you.","title":"PlugLoopback.request/5","ref":"PlugLoopback.html#request/5"},{"type":"function","doc":"```elixir\nMyAppWeb.Endpoint\n|> PlugLoopback.from_phoenix_endpoint()\n|> PlugLoopback.post(\"/api/user\", [{\"content-type\", \"application/json\"}, JSON.encode!(data)])\n|> PlugLoopback.run()\n```","title":"Example - PlugLoopback.request/5","ref":"PlugLoopback.html#request/5-example"},{"type":"function","doc":"Runs a request created by functions of this module","title":"PlugLoopback.run/1","ref":"PlugLoopback.html#run/1"},{"type":"exception","doc":"Error raised when the endpoint is not configured and the operation cannot succeed\n\nAn endpoint is configured when `PlugLoopback.replay/1` is called on a conn that has been through\na Phoenix endpoint, or when `PlugLoopback.from_phoenix_endpoint/1` was used.","title":"PlugLoopback.EndpointNotConfiguredError","ref":"PlugLoopback.EndpointNotConfiguredError.html"},{"type":"exception","doc":"Error raised when the request body is not fetched for POST, PUT or PATCH requests\n\nBody can be fetched using `Plug.Parsers`. Make sure to call this function after\nfetching the request body.","title":"PlugLoopback.RequestBodyNotFetchedError","ref":"PlugLoopback.RequestBodyNotFetchedError.html"},{"type":"extras","doc":"# PlugLoopback\n\nA set of utils to programmatically call your own endpoints\n\nIt happens that sometimes you need to programmatically call your own endpoint (for instance Phoenix\nendpoint). One could use an HTTP client locally calling your own deployed instance, but it's\ncumbersome, hard to test and comes with an overhead.\n\nThis library intends to provide with a set of function to directly call your endpoint. It is very\nsimilar to `Phoenix.Conntest`.\n\nYou can form a new request from a Phoenix endpoint:\n\n```elixir\nMyAppWeb.Endpoint\n|> PlugLoopback.from_phoenix_endpoint()\n|> PlugLoopback.get(\"/some/path\", [{\"some\", \"header\"}])\n|> Plug.Conn.put_req_header(\"another\", \"header\")\n|> PlugLoopback.run()\n```\n\nor replay any `Plug.Conn{}`:\n\n```elixir\nconn\n|> PlugLoopback.replay()\n|> PlugLoopback.run() # Here is a very good opportunity to create an infinite loop!\n```","title":"PlugLoopback","ref":"readme.html"},{"type":"extras","doc":"```elixir\ndef deps do\n  [\n    {:plug_loopback, \"~> 0.1.0\"}\n  ]\nend\n```","title":"Installation - PlugLoopback","ref":"readme.html#installation"},{"type":"extras","doc":"Requires Elixir 1.18+","title":"Support - PlugLoopback","ref":"readme.html#support"},{"type":"extras","doc":"The tricky part when copying a conn is to reset the initial body. Check the support in the following\nlist:\n- [x] JSON\n- [x] URL-encoded\n- [ ] multipart\n- [ ] custom body","title":"Replay request body - PlugLoopback","ref":"readme.html#replay-request-body"},{"type":"extras","doc":"# CHANGELOG\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on Keep a Changelog and this project adheres to Semantic Versioning.\n\n## [0.1.0] - 2025-05-17\n\nInitial release","title":"CHANGELOG","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}